---
sidebar_position: 14
---

# Special Win Setup

---

## Overview

Special Wins are high-value reward events in slot games, categorized based on the payout threshold:

| Win Type  | Trigger Threshold     | Visual Preview |
|-----------|-----------------------|----------------|
| **Big Win**   | Medium payout         | ![Big](../img/05-main-scene/special-win-big.png) |
| **Super Win** | High payout           | ![Super](../img/05-main-scene/special-win-super.png) |
| **Mega Win**  | Maximum payout        | ![Mega](../img/05-main-scene/special-win-mega.png) |

Each type delivers increasing visual excitement to highlight significant player rewards.

---

## Implementation

### Core Components

The special win system consists of three main components:

| Component | Purpose |
|-----------|---------|
| `hyper-special-win-initializer` | Handles system initialization and setup |
| `hyper-present-special-win` | Manages animation sequences and display logic |
| `hyper-special-win-label-point-effect` | Controls win amount visualization |

![Component Architecture](../img/05-main-scene/special-win-in-game.png)

#### Coin Effect System

The coin shower effect uses prefab variants for different markets:

![Base Coin Asset](../img/05-main-scene/special-win-coin.png)

| Prefab Name | Market Target | Asset Preview |
|-------------|---------------|---------------|
| `hyper-coin-shower-international` | Global markets | ![International Version](../img/05-main-scene/special-win-coin-internation.png) |
| `hyper-coin-shower-chinese` | Chinese market | ![Chinese Version](../img/05-main-scene/special-win-coin-chinese.png) |

:::tip
Position the Special Win node as per game design
:::

---

### Asset Configuration

#### 1. Static Resources

Store static assets in platform-specific directories:

| Platform | Path | Preview |
|----------|------|---------|
| Desktop  | `assets/textures/desktop/presloads/special-wins` | ![Desktop](../img/05-main-scene/special-win-folder-desktop.png) |
| Mobile   | `assets/textures/mobile/presloads/special-wins`  | ![Mobile](../img/05-main-scene/special-win-folder-mobile.png) |

[View Platform Asset Structure](http://localhost:3000/docs/category/game-asset-structure)

---

#### 2. Animation Setup

##### Special Win Animation Flow

```mermaid
%%{init: {'theme': 'base', 'themeVariables': { 'fontSize': '25px', 'fontFamily': 'arial' }}}%%
graph TD
    %% Win Types with Thresholds
    SW[Special Wins] --> BW["Big Win"]
    SW --> SPW["Super Win"]
    SW --> MW["Mega Win"]

    %% Big Win stages with flow
    BW --> BWI[bigwin-in]
    BWI --> BWL[bigwin-loop]
    BWL --> BWO[bigwin-out]

    %% Super Win stages with flow
    SPW --> SPWI[superwin-in]
    SPWI --> SPWL[superwin-loop]
    SPWL --> SPWO[superwin-out]

    %% Mega Win stages with flow
    MW --> MWI[megawin-in]
    MWI --> MWL[megawin-loop]
    MWL --> MWO[megawin-out]

     %% Legend nodes
    L0["Feature Name"]-->L1["Win Types"] --> L2["In Stage"] --> L3["Loop Stage"] --> L4["Out Stage"]
    class L0 specialWin
    class L1 winType
    class L2 inStage
    class L3 loopStage
    class L4 outStage

    %% Style definitions
    classDef inStage fill:#e6f3ff,stroke:#666,font-size:25px
    classDef loopStage fill:#fff2cc,stroke:#666,font-size:25px
    classDef outStage fill:#f8cecc,stroke:#666,font-size:25px
    classDef winType fill:#d5e8d4,stroke:#82b366,font-size:25px
    classDef specialWin fill:#fff4dd,stroke:#ff0000,font-size:25px

    class BWI,SPWI,MWI inStage
    class BWL,SPWL,MWL loopStage
    class BWO,SPWO,MWO outStage
    class BW,SPW,MW winType
    class SW specialWin

    %% Adjust node spacing
    linkStyle default stroke-width:4px
```
    ![Type Names](../img/05-main-scene/special-win-type-name.png)

##### Step 1: Add Animation Resources

Place animated assets in the following directories:

| Platform | Path | Preview |
|----------|------|---------|
| Desktop  | `assets/textures/desktop/postloads/custom-scale/anim-special-win` | ![Desktop](../img/05-main-scene/special-win-folder-desktop-anim.png) |
| Mobile   | `assets/textures/mobile/postloads/custom-scale/anim-special-win`  | ![Mobile](../img/05-main-scene/special-win-folder-mobile-anim.png) |

##### Step 2: Configure Animation Settings

| Setting         | Example |
|------------------|---------|
| Static Fallback  | ![Static](../img/05-main-scene/special-win-static.png) |
| Loop Animation   | ![Loop](../img/05-main-scene/special-win-loop.png) |

[View Animation Provider Setup](http://localhost:3000/docs/setup-main-game/main-scene/system#animation-provider-setup)

:::tip
Static and animation folder paths may vary by game. Adjust as needed.
:::

##### Step 3: Font Configuration

- **Path:** `assets\game-assets\fonts\preloads\main-game\fnt-special-win`         
- Follow these steps to configure fonts for special win displays:         

1. **Package Font Assets**
   - Import font files into project
   ![Font Packaging](../img/05-main-scene/special-win-pack-font.png)

2. **Font Integration**
   - Add font asset to special win component
   ![Font Integration](../img/05-main-scene/special-win-font.png)

3. **Layout Settings**
   - Configure text alignment
   - Adjust font size and spacing
   ![Font Layout](../img/05-main-scene/special-win-font-align.png)

:::tip
Customize font styles based on each game's design.
:::
